Version 1.0.0 (2018-10-31)

We closed a total of 15 issues (enhancements and bug fixes) through 7 pull requests, since our last release on 2018-07-18.

## Issues Closed
  - get ready for the first release and the launch of online docs (#9)
  - Fixes doctests (#8)
  - Change setup to handle version pragmatically (#6)
  - accounting for libpysal api changes in unittests (#5)
  - missing parenthesis in call to print (#2)
  - setting up dual testing (#4)
  - 2to3 for _indices.py (#3)
  - Initial setup (#1)

## Pull Requests
  - get ready for the first release and the launch of online docs (#9)
  - Fixes doctests (#8)
  - Change setup to handle version pragmatically (#6)
  - accounting for libpysal api changes in unittests (#5)
  - setting up dual testing (#4)
  - 2to3 for _indices.py (#3)
  - Initial setup (#1)

The following individuals contributed to this release:

  - Serge Rey
  - Wei Kang
  - Levi John Wolf